@@ -2,7 +2,7 @@ package Org::Export::Text;
 
 use 5.010001;
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 1;
 # ABSTRACT: Export Org document to text
@@ -19,7 +19,7 @@ Org::Export::Text - Export Org document to text
 
 =head1 VERSION
 
-This document describes version 0.001 of Org::Export::Text (from Perl distribution Org-To-Text), released on 2014-08-16.
+This document describes version 0.02 of Org::Export::Text (from Perl distribution Org-To-Text), released on 2015-08-18.
 
 =head1 HOMEPAGE
 
@@ -27,7 +27,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Org-To-Tex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Org-To-Text>.
+Source repository is at L<https://github.com/perlancar/perl-Org-To-Text>.
 
 =head1 BUGS
 
@@ -39,11 +39,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
